@@ -21,21 +21,22 @@
  *
  */
 
-#include "translate.h"
 #include "motion.h"
+#include "translate.h"
 #include "util.h"
 #include "logger.h"
 #include "dbse.h"
 
-/**
- * dbse_global_deinit
- *
- */
+pthread_mutex_t dbse_lock;
+
+/** dbse_global_deinit */
 void dbse_global_deinit(struct context **cntlist)
 {
     struct context *cnt;
     int i;
 
+    pthread_mutex_destroy(&dbse_lock);
+
     #if defined(HAVE_MYSQL)
         for (cnt=cntlist[i=0]; cnt; cnt=cntlist[++i]) {
             if (mystreq(cnt->conf.database_type, "mysql")) {
@@ -64,16 +65,15 @@ void dbse_global_deinit(struct context **cntlist)
     }
 }
 
-/**
- * dbse_global_init
- *
- */
+/** dbse_global_init */
 void dbse_global_init(struct context **cntlist)
 {
     int indx;
 
     MOTION_LOG(DBG, TYPE_DB, NO_ERRNO,_("Initializing database"));
 
+    pthread_mutex_init(&dbse_lock, NULL);
+
     /* Initialize all the database items; different camera threads can use different DBMSs */
     #if defined(HAVE_MYSQL)
         indx = 0;
@@ -101,45 +101,7 @@ void dbse_global_init(struct context **cntlist)
         }
     #endif /* HAVE_MARIADB */
 
-    #if defined(HAVE_SQLITE3)
-        /* database_sqlite3 == NULL if not changed causes each thread to create their own
-        * sqlite3 connection this will only happens when using a non-threaded sqlite version */
-        cntlist[0]->database_sqlite3=NULL;
-        if (cntlist[0]->conf.database_type && ((mystreq(cntlist[0]->conf.database_type, "sqlite3")) && cntlist[0]->conf.database_dbname)) {
-            MOTION_LOG(NTC, TYPE_DB, NO_ERRNO
-                ,_("SQLite3 Database filename %s")
-                ,cntlist[0]->conf.database_dbname);
-
-            int thread_safe = sqlite3_threadsafe();
-            if (thread_safe > 0) {
-                MOTION_LOG(NTC, TYPE_DB, NO_ERRNO, _("SQLite3 is threadsafe"));
-                MOTION_LOG(NTC, TYPE_DB, NO_ERRNO, _("SQLite3 serialized %s")
-                    ,(sqlite3_config(SQLITE_CONFIG_SERIALIZED)?_("FAILED"):_("SUCCESS")));
-                if (sqlite3_open( cntlist[0]->conf.database_dbname, &cntlist[0]->database_sqlite3) != SQLITE_OK) {
-                    MOTION_LOG(ERR, TYPE_DB, NO_ERRNO
-                        ,_("Can't open SQLite3 database %s : %s")
-                        ,cntlist[0]->conf.database_dbname
-                        ,sqlite3_errmsg( cntlist[0]->database_sqlite3));
-                    sqlite3_close( cntlist[0]->database_sqlite3);
-                    exit(1);
-                }
-                MOTION_LOG(NTC, TYPE_DB, NO_ERRNO,_("database_busy_timeout %d msec"),
-                        cntlist[0]->conf.database_busy_timeout);
-                if (sqlite3_busy_timeout( cntlist[0]->database_sqlite3,  cntlist[0]->conf.database_busy_timeout) != SQLITE_OK) {
-                    MOTION_LOG(ERR, TYPE_DB, NO_ERRNO,_("database_busy_timeout failed %s")
-                        ,sqlite3_errmsg( cntlist[0]->database_sqlite3));
-                }
-            }
-        }
-        /* Cascade to all threads */
-        indx = 1;
-        while (cntlist[indx] != NULL) {
-            cntlist[indx]->database_sqlite3 = cntlist[0]->database_sqlite3;
-            indx++;
-        }
-    #endif /* HAVE_SQLITE3 */
-
-    #if !defined(HAVE_MYSQL) && !defined(HAVE_MARIADB) && !defined(HAVE_SQLITE3)
+    #if !defined(HAVE_MYSQL) && !defined(HAVE_MARIADB)
         (void)indx;
         (void)cntlist;
     #endif
@@ -155,7 +117,6 @@ static int dbse_init_mysql(struct context *cnt)
     #if defined(HAVE_MYSQL)
         int dbport;
         if ((mystreq(cnt->conf.database_type, "mysql")) && (cnt->conf.database_dbname)) {
-            cnt->database_event_id = 0;
             cnt->database_mysql = mymalloc(sizeof(MYSQL));
             mysql_init(cnt->database_mysql);
             if ((cnt->conf.database_port < 0) || (cnt->conf.database_port > 65535)) {
@@ -195,7 +156,6 @@ static int dbse_init_mariadb(struct context *cnt)
     #if defined(HAVE_MARIADB)
         int dbport;
         if ((mystreq(cnt->conf.database_type, "mariadb")) && (cnt->conf.database_dbname)) {
-            cnt->database_event_id = 0;
             cnt->database_mariadb = mymalloc(sizeof(MYSQL));
             mysql_init(cnt->database_mariadb);
             if ((cnt->conf.database_port < 0) || (cnt->conf.database_port > 65535)) {
@@ -226,38 +186,37 @@ static int dbse_init_mariadb(struct context *cnt)
 
 }
 
-/**
- * dbse_init_sqlite3
- *
- */
-static int dbse_init_sqlite3(struct context *cnt,struct context **cntlist)
+/** dbse_init_sqlite3 */
+static int dbse_init_sqlite3(struct context *cnt)
 {
     #ifdef HAVE_SQLITE3
-        if (cntlist[0]->database_sqlite3 != 0) {
-            MOTION_LOG(NTC, TYPE_DB, NO_ERRNO,_("SQLite3 using shared handle"));
-            cnt->database_sqlite3 = cntlist[0]->database_sqlite3;
-
-        } else if ((mystreq(cnt->conf.database_type, "sqlite3")) && cnt->conf.database_dbname) {
+        int retcd;
+        if ((mystreq(cnt->conf.database_type, "sqlite3")) &&
+            (cnt->conf.database_dbname != NULL)) {
             MOTION_LOG(NTC, TYPE_DB, NO_ERRNO
-                ,_("SQLite3 Database filename %s"), cnt->conf.database_dbname);
-            if (sqlite3_open(cnt->conf.database_dbname, &cnt->database_sqlite3) != SQLITE_OK) {
+                ,_("Opening database %s"), cnt->conf.database_dbname);
+            retcd = sqlite3_open(cnt->conf.database_dbname, &cnt->database_sqlite3);
+            if (retcd != SQLITE_OK) {
                 MOTION_LOG(ERR, TYPE_DB, NO_ERRNO
-                    ,_("Can't open SQLite3 database %s : %s")
-                    ,cnt->conf.database_dbname, sqlite3_errmsg(cnt->database_sqlite3));
+                    ,_("Can't open SQLite3 database %s.  Error %d : %s")
+                    , cnt->conf.database_dbname, retcd
+                    , sqlite3_errmsg(cnt->database_sqlite3));
                 sqlite3_close(cnt->database_sqlite3);
                 return -2;
             }
             MOTION_LOG(NTC, TYPE_DB, NO_ERRNO
-                ,_("database_busy_timeout %d msec"), cnt->conf.database_busy_timeout);
-            if (sqlite3_busy_timeout(cnt->database_sqlite3, cnt->conf.database_busy_timeout) != SQLITE_OK) {
+                , _("Setting busy timeout to %d msec")
+                , cnt->conf.database_busy_timeout);
+            retcd = sqlite3_busy_timeout(cnt->database_sqlite3
+                , cnt->conf.database_busy_timeout);
+            if (retcd != SQLITE_OK) {
                 MOTION_LOG(ERR, TYPE_DB, NO_ERRNO
-                    ,_("database_busy_timeout failed %s")
-                    ,sqlite3_errmsg(cnt->database_sqlite3));
+                    , _("Setting busy timeout failed.  Error %d:%s")
+                    , retcd, sqlite3_errmsg(cnt->database_sqlite3));
             }
         }
     #else
         (void)cnt;
-        (void)cntlist;
     #endif /* HAVE_SQLITE3 */
 
     return 0;
@@ -273,11 +232,6 @@ static int dbse_init_pgsql(struct context *cnt)
     #ifdef HAVE_PGSQL
         if ((mystreq(cnt->conf.database_type, "postgresql")) && (cnt->conf.database_dbname)) {
             char connstring[255];
-
-            /*
-             * Create the connection string.
-             * Quote the values so we can have null values (blank)
-             */
             snprintf(connstring, 255,
                      "dbname='%s' host='%s' user='%s' password='%s' port='%d'",
                       cnt->conf.database_dbname, /* dbname */
@@ -290,12 +244,11 @@ static int dbse_init_pgsql(struct context *cnt)
             cnt->database_pgsql = PQconnectdb(connstring);
             if (PQstatus(cnt->database_pgsql) == CONNECTION_BAD) {
                 MOTION_LOG(ERR, TYPE_DB, NO_ERRNO
-                ,_("Connection to PostgreSQL database '%s' failed: %s")
-                ,cnt->conf.database_dbname, PQerrorMessage(cnt->database_pgsql));
+                    ,_("Connection to PostgreSQL database '%s' failed: %s")
+                    ,cnt->conf.database_dbname, PQerrorMessage(cnt->database_pgsql));
                 return -2;
             }
             cnt->eid_db_format = dbeid_undetermined;
-            cnt->database_event_id = 0;
         }
     #else
         (void)cnt;  /* Avoid compiler warnings */
@@ -304,17 +257,14 @@ static int dbse_init_pgsql(struct context *cnt)
     return 0;
 }
 
-/**
- * dbse_init
- *
- */
-int dbse_init(struct context *cnt, struct context **cntlist)
+/** dbse_init */
+int dbse_init(struct context *cnt)
 {
     int retcd = 0;
 
     if (cnt->conf.database_type) {
         MOTION_LOG(NTC, TYPE_DB, NO_ERRNO
-            ,_("Database backend %s"), cnt->conf.database_type);
+            ,_("Database type %s"), cnt->conf.database_type);
 
         if (mystreq(cnt->conf.database_type,"mysql")) {
             retcd = dbse_init_mysql(cnt);
@@ -323,7 +273,7 @@ int dbse_init(struct context *cnt, struct context **cntlist)
         } else if (mystreq(cnt->conf.database_type,"postgresql")) {
             retcd = dbse_init_pgsql(cnt);
         } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
-            retcd = dbse_init_sqlite3(cnt, cntlist);
+            retcd = dbse_init_sqlite3(cnt);
         }
 
         /* Set the sql mask file according to the SQL config options*/
@@ -347,7 +297,6 @@ void dbse_deinit(struct context *cnt)
             if ( (mystreq(cnt->conf.database_type, "mysql")) && (cnt->conf.database_dbname)) {
                 mysql_thread_end();
                 mysql_close(cnt->database_mysql);
-                cnt->database_event_id = 0;
             }
         #endif /* HAVE_MYSQL */
 
@@ -355,7 +304,6 @@ void dbse_deinit(struct context *cnt)
             if ( (mystreq(cnt->conf.database_type, "mariadb")) && (cnt->conf.database_dbname)) {
                 mysql_thread_end();
                 mysql_close(cnt->database_mariadb);
-                cnt->database_event_id = 0;
             }
         #endif /* HAVE_MARIADB */
 
@@ -363,16 +311,14 @@ void dbse_deinit(struct context *cnt)
                 if ((mystreq(cnt->conf.database_type, "postgresql")) && (cnt->conf.database_dbname)) {
                     PQfinish(cnt->database_pgsql);
                     cnt->database_pgsql = NULL;
-                    cnt->database_event_id = 0;
                 }
         #endif /* HAVE_PGSQL */
 
         #ifdef HAVE_SQLITE3
-                /* Close the SQLite database */
-                if ((mystreq(cnt->conf.database_type, "sqlite3")) && (cnt->conf.database_dbname)) {
-                    sqlite3_close(cnt->database_sqlite3);
-                    cnt->database_sqlite3 = NULL;
-                }
+            if (cnt->database_sqlite3 != NULL) {
+                sqlite3_close(cnt->database_sqlite3);
+                cnt->database_sqlite3 = NULL;
+            }
         #endif /* HAVE_SQLITE3 */
         (void)cnt;
     }
@@ -399,7 +345,7 @@ void dbse_sqlmask_update(struct context *cnt)
  * dbse_exec_mysql
  *
  */
-static void dbse_exec_mysql(char *sqlquery, struct context *cnt, int save_id)
+static void dbse_exec_mysql(char *sqlquery, struct context *cnt)
 {
     #if defined(HAVE_MYSQL)
         if (mystreq(cnt->conf.database_type, "mysql")) {
@@ -440,14 +386,10 @@ static void dbse_exec_mysql(char *sqlquery, struct context *cnt, int save_id)
                     }
                 }
             }
-            if (save_id) {
-                cnt->database_event_id = (unsigned long long) mysql_insert_id(cnt->database_mysql);
-            }
         }
     #else
         (void)sqlquery;
         (void)cnt;
-        (void)save_id;
     #endif /* HAVE_MYSQL*/
 }
 
@@ -455,7 +397,7 @@ static void dbse_exec_mysql(char *sqlquery, struct context *cnt, int save_id)
  * dbse_exec_mariadb
  *
  */
-static void dbse_exec_mariadb(char *sqlquery, struct context *cnt, int save_id)
+static void dbse_exec_mariadb(char *sqlquery, struct context *cnt)
 {
     #if defined(HAVE_MARIADB)
         if (mystreq(cnt->conf.database_type, "mariadb")) {
@@ -496,14 +438,10 @@ static void dbse_exec_mariadb(char *sqlquery, struct context *cnt, int save_id)
                     }
                 }
             }
-            if (save_id) {
-                cnt->database_event_id = (unsigned long long) mysql_insert_id(cnt->database_mariadb);
-            }
         }
     #else
         (void)sqlquery;
         (void)cnt;
-        (void)save_id;
     #endif /* HAVE_MYSQL HAVE_MARIADB*/
 
 }
@@ -512,7 +450,7 @@ static void dbse_exec_mariadb(char *sqlquery, struct context *cnt, int save_id)
  * dbse_exec_pgsql
  *
  */
-static void dbse_exec_pgsql(char *sqlquery, struct context *cnt, int save_id)
+static void dbse_exec_pgsql(char *sqlquery, struct context *cnt)
 {
     #ifdef HAVE_PGSQL
         if (mystreq(cnt->conf.database_type, "postgresql") && cnt->database_pgsql) {
@@ -561,47 +499,6 @@ static void dbse_exec_pgsql(char *sqlquery, struct context *cnt, int save_id)
             } else if (!(estat == PGRES_COMMAND_OK || estat == PGRES_TUPLES_OK)) {
                 MOTION_LOG(ERR, TYPE_DB, SHOW_ERRNO, _("PGSQL query failed: [%s]  %s %s"),
                     sqlquery, PQresStatus(PQresultStatus(res)), PQresultErrorMessage(res));
-            } else if (save_id) {
-                /* sqlquery processing is complete unless it potentially returns an event ID value;
-                 * save_id optionally allows SQL INSERT RETURNING a single positive integer value,
-                 * e.g., an auto-incremented unique row ID. */
-                if (cnt->eid_db_format < dbeid_undetermined) {
-                    /* A previous successful sqlquery returned nothing or an invalid value. This
-                     * is either intended or a non-transient flaw in a table schema or sqlquery. */
-                } else {
-                    if (estat == PGRES_TUPLES_OK) {  /* returned DB record set (possibly empty) */
-                        if (PQntuples(res) == 1 && PQnfields(res) == 1 && !PQgetisnull(res, 0, 0) && \
-                            ((cnt->eid_db_format=PQfformat(res, 0)) == 0)) {  /* got one char string */
-                            /* PQfformat()==0: null-term string, guaranteed unless DECLARE CURSOR BINARY
-                             * or extended query protocol (PGSQL Doc.sec.51.2.2; PGSQL>v9, 52.2.2) */
-                            char *eid_db_val;
-                            char *endptr;
-                            eid_db_val = PQgetvalue(res, 0, 0);
-                            MOTION_LOG(DBG, TYPE_DB, NO_ERRNO, _("INSERT ... RETURNING VALUE=\"%s\""),
-                                eid_db_val);
-                            cnt->database_event_id = strtoll(eid_db_val, &endptr, 10);
-                            /* "unsigned" dcl overriden by cast, else "<1" test fails if negative */
-                            if (*endptr != '\0' || (long long)cnt->database_event_id < 1) {
-                                /* not numeric or not positive or not integer */
-                                cnt->eid_db_format = dbeid_not_valid;  /* abandon event ID retrieval */
-                            }
-                        } else if (PQntuples(res) < 1) {  /* returned empty record set */
-                            cnt->eid_db_format = dbeid_no_return;
-                        } else {  /* returned NULL, BINARY value, multiple values, or muliple records */
-                            cnt->eid_db_format = dbeid_not_valid;  /* abandon event ID retrieval */
-                        }
-                    } else {  /* nothing returned; OK if %{dbeventid} never used */
-                        cnt->eid_db_format = dbeid_no_return;
-                    }
-                    if (cnt->eid_db_format == dbeid_not_valid) {
-                        MOTION_LOG(ERR, TYPE_DB, NO_ERRNO, _("Invalid event ID returned by SQL query \"%s\""),
-                        sqlquery);
-                    }
-                    if (cnt->eid_db_format && cnt-> database_event_id) {
-                        /* retrieval failed; nullify any earlier retrieved value */
-                        cnt->database_event_id = 0;
-                    }
-                }
             }
             if (res) {
                 PQclear(res);
@@ -610,46 +507,33 @@ static void dbse_exec_pgsql(char *sqlquery, struct context *cnt, int save_id)
     #else
         (void)sqlquery;
         (void)cnt;
-        (void)save_id;
     #endif /* HAVE_PGSQL */
 
 }
 
-/**
- * dbse_exec_sqlite3
- *
- */
-static void dbse_exec_sqlite3(char *sqlquery, struct context *cnt, int save_id)
+/** dbse_exec_sqlite3 */
+static void dbse_exec_sqlite3(char *sqlquery, struct context *cnt)
 {
     #ifdef HAVE_SQLITE3
-        if ((mystreq(cnt->conf.database_type, "sqlite3")) && (cnt->conf.database_dbname)) {
-            int res;
-            char *errmsg = 0;
-            MOTION_LOG(DBG, TYPE_DB, NO_ERRNO, _("Executing SQLite3 query"));
-            res = sqlite3_exec(cnt->database_sqlite3, sqlquery, NULL, 0, &errmsg);
-            if (res != SQLITE_OK ) {
-                MOTION_LOG(ERR, TYPE_DB, NO_ERRNO, _("SQLite3 error was %s"), errmsg);
+        if (cnt->database_sqlite3 != NULL) {
+            int retcd;
+            char *errmsg = NULL;
+            MOTION_LOG(DBG, TYPE_DB, NO_ERRNO, _("Executing %s"), sqlquery);
+            retcd = sqlite3_exec(cnt->database_sqlite3, sqlquery, NULL, 0, &errmsg);
+            if (retcd != SQLITE_OK ) {
+                MOTION_LOG(ERR, TYPE_DB, NO_ERRNO
+                    , _("SQLite3 error %d : %s"), retcd, errmsg);
                 sqlite3_free(errmsg);
-                if (save_id) {
-                    cnt->database_event_id = 0;
-                }
-            } else if (save_id) {
-                cnt->database_event_id = sqlite3_last_insert_rowid(cnt->database_sqlite3);
             }
-
         }
     #else
         (void)sqlquery;
         (void)cnt;
-        (void)save_id;
     #endif /* HAVE_SQLITE3 */
 
 }
 
-/**
- * dbse_firstmotion
- *
- */
+/** dbse_firstmotion */
 void dbse_firstmotion(struct context *cnt)
 {
     char sqlquery[PATH_MAX];
@@ -658,26 +542,25 @@ void dbse_firstmotion(struct context *cnt)
                    &cnt->current_image->timestamp_tv, NULL, 0);
 
     if (strlen(sqlquery) <= 0) {
-        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, "Ignoring empty sql query");
+        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, _("Ignoring empty sql query"));
         return;
     }
 
-    if (mystreq(cnt->conf.database_type,"mysql")) {
-        dbse_exec_mysql(sqlquery, cnt, 1);
-    } else if (mystreq(cnt->conf.database_type,"mariadb")) {
-        dbse_exec_mariadb(sqlquery, cnt, 1);
-    } else if (mystreq(cnt->conf.database_type,"postgresql")) {
-        dbse_exec_pgsql(sqlquery, cnt, 1);
-    } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
-        dbse_exec_sqlite3(sqlquery, cnt, 1);
-    }
+    pthread_mutex_lock(&dbse_lock);
+        if (mystreq(cnt->conf.database_type,"mysql")) {
+            dbse_exec_mysql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"mariadb")) {
+            dbse_exec_mariadb(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"postgresql")) {
+            dbse_exec_pgsql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
+            dbse_exec_sqlite3(sqlquery, cnt);
+        }
+    pthread_mutex_unlock(&dbse_lock);
 
 }
 
-/**
- * dbse_newfile
- *
- */
+/** dbse_newfile */
 void dbse_newfile(struct context *cnt, char *filename, int sqltype, struct timeval *tv1)
 {
     char sqlquery[PATH_MAX];
@@ -686,26 +569,25 @@ void dbse_newfile(struct context *cnt, char *filename, int sqltype, struct timev
                    tv1, filename, sqltype);
 
     if (strlen(sqlquery) <= 0) {
-        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, "Ignoring empty sql query");
+        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, _("Ignoring empty sql query"));
         return;
     }
 
-    if (mystreq(cnt->conf.database_type,"mysql")) {
-        dbse_exec_mysql(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"mariadb")) {
-        dbse_exec_mariadb(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"postgresql")) {
-        dbse_exec_pgsql(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
-        dbse_exec_sqlite3(sqlquery, cnt, 0);
-    }
+    pthread_mutex_lock(&dbse_lock);
+        if (mystreq(cnt->conf.database_type,"mysql")) {
+            dbse_exec_mysql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"mariadb")) {
+            dbse_exec_mariadb(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"postgresql")) {
+            dbse_exec_pgsql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
+            dbse_exec_sqlite3(sqlquery, cnt);
+        }
+    pthread_mutex_unlock(&dbse_lock);
 
 }
 
-/**
- * dbse_fileclose
- *
- */
+/** dbse_fileclose */
 void dbse_fileclose(struct context *cnt, char *filename, int sqltype, struct timeval *tv1)
 {
     char sqlquery[PATH_MAX];
@@ -713,18 +595,21 @@ void dbse_fileclose(struct context *cnt, char *filename, int sqltype, struct tim
     mystrftime(cnt, sqlquery, sizeof(sqlquery), cnt->conf.sql_query_stop,
                tv1, filename, sqltype);
     if (strlen(sqlquery) <= 0) {
-        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, "Ignoring empty sql query");
+        MOTION_LOG(WRN, TYPE_DB, NO_ERRNO, _("Ignoring empty sql query"));
         return;
     }
 
-    if (mystreq(cnt->conf.database_type,"mysql")) {
-        dbse_exec_mysql(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"mariadb")) {
-        dbse_exec_mariadb(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"postgresql")) {
-        dbse_exec_pgsql(sqlquery, cnt, 0);
-    } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
-        dbse_exec_sqlite3(sqlquery, cnt, 0);
-    }
+    pthread_mutex_lock(&dbse_lock);
+        if (mystreq(cnt->conf.database_type,"mysql")) {
+            dbse_exec_mysql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"mariadb")) {
+            dbse_exec_mariadb(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"postgresql")) {
+            dbse_exec_pgsql(sqlquery, cnt);
+        } else if (mystreq(cnt->conf.database_type,"sqlite3")) {
+            dbse_exec_sqlite3(sqlquery, cnt);
+        }
+    pthread_mutex_unlock(&dbse_lock);
+
 }
 
