@@ -27,15 +27,13 @@
 
 int nls_enabled;
 
+/* Testing routine for code development only.
+ * Does nothing in normal operations and just returns.
+*/
 void translate_locale_chg(const char *langcd)
 {
     #ifdef HAVE_GETTEXT
-        /* This routine is for development testing only.  It is not used for
-        * regular users because once this locale is change, it changes the
-        * whole computer over to the new locale.  Therefore, we just return
-        */
         return;
-
         setenv ("LANGUAGE", langcd, 1);
         /* Invoke external function to change locale*/
         ++_nl_msg_cat_cntr;
@@ -46,30 +44,27 @@ void translate_locale_chg(const char *langcd)
     #endif
 }
 
-void translate_init(void)
+void translate_init(struct context *cnt)
 {
     #ifdef HAVE_GETTEXT
-        /* Set the flag to enable native language support */
-        nls_enabled = 1;
-
-        setlocale (LC_ALL, "");
-
-        //translate_locale_chg("li");
-        translate_locale_chg("es");
-
-        bindtextdomain ("motion", LOCALEDIR);
-        bind_textdomain_codeset ("motion", "UTF-8");
-        textdomain ("motion");
-
+        if (cnt->conf.native_language == 1) {
+            nls_enabled = 1;
+            setlocale (LC_ALL, "");
+            bindtextdomain ("motion", LOCALEDIR);
+            bind_textdomain_codeset ("motion", "UTF-8");
+            textdomain ("motion");
+        } else {
+            nls_enabled = 0;
+        }
         MOTION_LOG(NTC, TYPE_ALL, NO_ERRNO,_("Language: English"));
-
     #else
-        /* Disable native language support */
         nls_enabled = 0;
-
-        /* This avoids a unused function warning */
-        translate_locale_chg("en");
+        (void)cnt;
     #endif
+
+    if (nls_enabled == 1) {
+        translate_locale_chg("es"); /* This is a testing only function call*/
+    }
 }
 
 char* translate_text(const char *msgid)
