@@ -555,15 +555,6 @@ void vid_mutex_destroy(void)
 void vid_close(struct context *cnt)
 {
 
-    #ifdef HAVE_MMAL
-        if (cnt->mmalcam) {
-            MOTION_LOG(INF, TYPE_VIDEO, NO_ERRNO,_("calling mmalcam_cleanup"));
-            mmalcam_cleanup(cnt->mmalcam);
-            cnt->mmalcam = NULL;
-            return;
-        }
-    #endif
-
     if (cnt->netcam) {
         MOTION_LOG(INF, TYPE_VIDEO, NO_ERRNO,_("calling netcam_cleanup"));
         netcam_cleanup(cnt->netcam, 0);
@@ -590,7 +581,7 @@ void vid_close(struct context *cnt)
         return;
     }
 
-    MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO,_("No Camera device cleanup (MMAL, Netcam, V4L2, BKTR)"));
+    MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO,_("No Camera device cleanup (Netcam, V4L2, BKTR)"));
     return;
 
 }
@@ -621,19 +612,6 @@ int vid_start(struct context *cnt)
 {
     int dev = -1;
 
-    #ifdef HAVE_MMAL
-        if (cnt->camera_type == CAMERA_TYPE_MMAL) {
-            MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO,_("Opening MMAL cam"));
-            dev = mmalcam_start(cnt);
-            if (dev < 0) {
-                mmalcam_cleanup(cnt->mmalcam);
-                cnt->mmalcam = NULL;
-                MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO,_("MMAL cam failed to open"));
-            }
-            return dev;
-        }
-    #endif
-
     if (cnt->camera_type == CAMERA_TYPE_NETCAM) {
         MOTION_LOG(NTC, TYPE_VIDEO, NO_ERRNO,_("Opening Netcam"));
         dev = netcam_start(cnt);
@@ -674,7 +652,7 @@ int vid_start(struct context *cnt)
     }
 
     MOTION_LOG(ERR, TYPE_VIDEO, NO_ERRNO
-        ,_("No Camera device specified (MMAL, Netcam, V4L2, BKTR)"));
+        ,_("No Camera device specified (Netcam, V4L2, BKTR)"));
     return dev;
 
 }
@@ -702,15 +680,6 @@ int vid_start(struct context *cnt)
 int vid_next(struct context *cnt, struct image_data *img_data)
 {
 
-    #ifdef HAVE_MMAL
-        if (cnt->camera_type == CAMERA_TYPE_MMAL) {
-            if (cnt->mmalcam == NULL) {
-                return NETCAM_GENERAL_ERROR;
-            }
-            return mmalcam_next(cnt, img_data);
-        }
-    #endif
-
     if (cnt->camera_type == CAMERA_TYPE_NETCAM) {
         if (cnt->video_dev == -1) {
             return NETCAM_GENERAL_ERROR;
